@@ -3,8 +3,7 @@
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
-#ifndef KDECORATION2_DECORATIONBUTTON_P_H
-#define KDECORATION2_DECORATIONBUTTON_P_H
+#pragma once
 
 #include "decorationbutton.h"
 
@@ -76,5 +75,3 @@ private:
 };
 
 }
-
-#endif
